===============================
flask-htmlbuilder
===============================

.. image:: https://img.shields.io/travis/quokkaproject/flask-htmlbuilder.svg
        :target: https://travis-ci.org/quokkaproject/flask-htmlbuilder

.. image:: https://img.shields.io/pypi/v/flask-htmlbuilder.svg
        :target: https://pypi.python.org/pypi/flask-htmlbuilder


HTML builder for Python and Flask

  Flask-HTMLBuilder
    ~~~~~~~~~~~~~~~~~

    Flask-HTMLBuilder is a Flask extension that allows flexible and easy
    Python-only generation of HTML snippets and full HTML documents using a
    robust syntax.  For more advanced usage it provides a lean template
    inheritance system that is intertwined with the Flask/Werkzeug endpoint
    mechanisms.
    
    Forked from: http://majorz.github.com/flask-htmlbuilder/
